@@ -1,8 +1,7 @@
 import os
 import time
-import collections
 import tempfile
-import math
+import shutil
 import xml.etree.ElementTree as ET
 from selenium import webdriver
 from gmapsbounds import utils
@@ -17,15 +16,15 @@ class Location:
         self.save_dir = tempfile.mkdtemp()
         self.center = ''
         self.zoom = ''
-        self.nodes = []
+        self.polygons = []
 
     def download_center_map(self):
         self.load_map()
         self.center, self.zoom = utils.parse_url(self.driver.current_url)
         center_list = [float(coord) for coord in self.center.split(', ')]
-        self.offset = llpx.lat_lng_to_pixels(center_list[0], center_list[1], self.zoom)
         if self.center in constants.ZOOM_OUT:
             self.zoom_out()
+        self.offset = llpx.lat_lng_to_pixels(center_list[0], center_list[1], self.zoom)
         self.take_map_screenshot('boundaries.png')
 
     def zoom_out(self):
@@ -42,58 +41,32 @@ class Location:
             self.driver.current_url.split('/')[:5] or '@' not in self.driver.current_url):
             pass
 
-    def load_map_detailed(self, lat_lng, zoom):
-        self.driver.get('https://www.google.com/maps/place/{}/@{},{}z'.format(
-        self.name.replace(' ', '+'), lat_lng.replace(' ', ''), zoom))
-
     def take_map_screenshot(self, filename):
         container = self.driver.find_element_by_class_name('widget-scale')
         # clicking this closes the ad panel
         container.click()
-        time.sleep(5)
+        time.sleep(1)
         self.driver.save_screenshot(os.path.join(self.save_dir, filename))
-        self.driver.save_screenshot(filename)
+        shutil.copyfile(os.path.join(self.save_dir, filename), filename)
 
     def calculate_coordinates(self):
         boundaries_filename = os.path.join(self.save_dir, 'boundaries.png')
         rgb_im = utils.load_image(boundaries_filename)
         nodes = reader.get_nodes(rgb_im)
-        self.nodes = reader.order_nodes(nodes, rgb_im)
-        self.nodes = utils.prune_nodes(self.nodes)
-        self.nodes = utils.remove_overlapping_polygons(self.nodes)
+        self.polygons = reader.get_polygons(nodes, rgb_im)
+        self.polygons = reader.prune_nodes(self.polygons)
+        self.polygons = reader.trim_overlapping_nodes(self.polygons)
         self.pixcenter = [rgb_im.size[0] // 2, rgb_im.size[1] // 2]
-        for node_collection in self.nodes:
-            for node in node_collection:
+        for poly in self.polygons:
+            for node in poly.nodes:
                 node.location = self
-        with open('cityarray.js', 'w') as f:
-            f.write('var COORDINATES = [\n')
-            for node_collection in self.nodes:
-                f.write('[\n')
-                for node in node_collection:
-                    lat, lng = node.get_lat_lng()
-                    f.write('new google.maps.LatLng({}, {}),\n'.format(lat, lng))
-                f.write('],\n')    
-            f.write('];\n')
-            f.write('\n')
-            f.write('var INFO = "{}, {}";'.format(self.center, self.zoom))
-
-    def as_dict(self):
-        boundaries = []
-        center_list = [float(coord) for coord in self.center.split(', ')]
-        for node_collection in self.nodes:
-            boundaries.append([node.get_lat_lng() for node in node_collection])
-        return collections.OrderedDict([
-            ['name', self.name],
-            ['center', center_list],
-            ['boundaries', boundaries]
-        ])
 
     def write_to_kml(self, filename):
         root = ET.Element('kml')
         root.set('xmlns', 'http://www.opengis.net/kml/2.2')
         placemark = ET.SubElement(root, 'Placemark')
         placemark.append(utils.makeelement('name', self.name))
-        for node_collection in self.nodes:
+        for poly in self.polygons:
             polygon = ET.SubElement(placemark, 'Polygon')
             polygon.append(utils.makeelement('extrude', '1'))
             polygon.append(utils.makeelement('altitudeMode', 'relativeToGround'))
@@ -101,9 +74,10 @@ class Location:
             linear_ring = ET.SubElement(boundary, 'LinearRing')
             coordinates = ET.SubElement(linear_ring, 'coordinates')
             text_list = []
-            for node in node_collection:
+            for node in poly.nodes:
                 coords_as_strings = [str(coord) for coord in node.get_lat_lng()]
                 text_list.append(','.join(reversed(coords_as_strings)))
             coordinates.text = '\n'.join(text_list)
         with open(filename, 'w') as f:
             f.write(ET.tostring(root).decode('utf8'))
+
