@@ -1,9 +1,17 @@
 import os
 import re
 import time
+from PIL import Image
+import xml.etree.ElementTree as ET
+import xvfbwrapper
 from selenium import webdriver
 from gmapsbounds import constants
 
+def load_image(filename):
+    im = Image.open(filename)
+    im.load()
+    return im.convert('RGB')
+
 def parse_url(url):
     spl = url.split('/')
     assert ['https:', '', 'www.google.com', 'maps', 'place'] == spl[:5]
@@ -26,59 +34,16 @@ def wait_until(func, arg, interval=1):
         except:
             time.sleep(interval)
 
-def poly_overlap(poly1, poly2):
-    i = -len(poly1) + 1
-    for point in poly1:
-        mx, my = get_midpoint(point, poly1[i])
-        # midpoint = reader.Node(mx, my)
-        if contains(point, poly2): # or contains(midpoint, poly2)
-            return True
-    return False
-
-def contains(point, polygon):
-    assert len(polygon) > 2
-    crossings = 0
-    i = -len(polygon) + 1
-    matched_y = set()
-    for node in polygon:
-        if ray_crosses_edge(point, node, polygon[i]):
-            if not point.y in matched_y:
-                matched_y.add(point.y)
-                crossings += 1
-        i += 1
-    return crossings % 2 == 1
-
 def ray_crosses_edge(point, v1, v2):
+    '''
+    Test whether a point lies within a polygon, excluding vertices and edges
+    '''
     # All three args are nodes with x and y properties
     # Ray goes north for this function
-    if point.x > max(v1.x, v2.x):
+    if (point.x > max(v1.x, v2.x) or point.x < min(v1.x, v2.x) or
+        point.y < min(v1.y, v2.y) or (v1.x == point.x and v1.x <= v2.x)):
         return False
-    if point.x < min(v1.x, v2.x):
-        return False
-    if point.y < min(v1.y, v2.y):
-        return False
-    if v1.x == v2.x:
-        return False
-    slope = (v2.y-v1.y) / (v2.x - v1.x)
-    if point.y <= v2.y - (v2.x - point.x) * slope:
-        return False
-    return True
-
-def remove_overlapping_polygons(polygons):
-    assert polygons
-    polygons.sort(key=len, reverse=True)
-    okay_polygons = [polygons[0]]
-    for test_polygon in polygons:
-        overlap = False
-        if test_polygon in okay_polygons:
-            continue
-        for okay_polygon in okay_polygons:
-            if poly_overlap(test_polygon, okay_polygon):
-                overlap = True
-                break
-        if not overlap:
-            okay_polygons.append(test_polygon)
-    return okay_polygons
+    return not (point.y <= v2.y - (v2.x - point.x) * get_slope(v1, v2))
 
 def max_length_list(alist):
     max_list = None
@@ -108,20 +73,6 @@ def is_water(r, g, b):
         return True
     return False
 
-def prune_nodes(nodes):
-    pruned_nodes = []
-    for node_collection in nodes:
-        assert len(node_collection) > 2
-        pruned_collection = node_collection[:2]
-        for node in node_collection[2:]:
-            if (get_slope(pruned_collection[-2], pruned_collection[-1]) == get_slope(pruned_collection[-2], node) or
-                get_distance(pruned_collection[-1], node)) <= 2:
-                pruned_collection.pop()
-            pruned_collection.append(node)
-        if len(pruned_collection) > 2:
-            pruned_nodes.append(pruned_collection)
-    return pruned_nodes
-
 def get_slope(node1, node2):
     try:
         return (node2.y-node1.y) / (node2.x - node1.x)
@@ -132,4 +83,39 @@ def get_distance(node1, node2):
     return((node1.x - node2.x)**2 + (node1.y - node2.y)**2)**.5
 
 def get_midpoint(node1, node2):
-    return (node1.x + (node2.x - node1.x) / 2, node1.y + (node2.y - node1.y) / 2)
\ No newline at end of file
+    return (node1.x + (node2.x - node1.x) / 2, node1.y + (node2.y - node1.y) / 2)
+
+def makeelement(tag, text=None, attributes=None, tail=None):
+    if attributes is None:
+        attributes = {}
+    newelement = ET.Element(tag)
+    for k, v in attributes.items():
+        newelement.set(k, v)
+    if text is not None: newelement.text = text
+    if tail is not None: newelement.tail = tail
+    return newelement
+
+
+def sort_by_polygon_length(polygons):
+    less = []
+    equal = []
+    greater = []
+    if len(polygons) > 1:
+        pivot = polygons[0]
+        for poly in polygons:
+            if len(poly.nodes) < len(pivot.nodes):
+                less.append(poly)
+            if len(poly.nodes) == len(pivot.nodes):
+                equal.append(poly)
+            if len(poly.nodes) > len(pivot.nodes):
+                greater.append(poly)
+        return sort_by_polygon_length(less) + equal + sort_by_polygon_length(greater)
+    return polygons
+
+def get_menu_borders(rgb_image):
+    for x in range(30, 430):
+        r, g, b = rgb_image.getpixel((x, 370))
+        if [r, g, b] != [255, 255, 255]:
+            return constants.MENU_BORDERS
+    return constants.MENU_BORDERS_WITH_ADS
+
